==> DhcpAdmin-1.0.tar.gz: DhcpAdmin/lib/libpost.pl <==
#
# dhcpadmin
#
# Copyright (C) 2008 DesigNET, INC.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

##########################################################
#
# POST饤֥
#
# $RCSfile: libpost.pl,v $
# $Revision: 1.10 $
# $Date: 2008/12/10 07:55:37 $
#
##########################################################

use strict;
use LWP::UserAgent;

##################饤֥ꥰХ##################
my $HTTPAGENT="DHCPADMIN";
my $CONTENTTYPE="application/x-www-form-urlencoded";
my $POSTSETCODE="&postset=1";
my $POSTRESULT="RET:OK";

#
# POST᥽åȯ
#
# []
#	arg0	POSTURL
#	arg1	POSTѥǡ
#	arg2	
#	arg3	顼
#
# [֤]
#	0	OK
#      -1	³顼
#
#

sub send_post_method
{
    my ($posturl, $postdata, $result, $errmsg) = @_;
    my $ua;
    my $req;
    my $res;

    # ꥯȳ
    $ua = new LWP::UserAgent;
    $ua->agent($HTTPAGENT . $ua->agent);

    # ꥯȤޤ
    $req = new HTTP::Request POST => $posturl;
    $req->content_type($CONTENTTYPE);
    $req->content($postdata . $POSTSETCODE);
    $req->authorization_basic($ENV{'REMOTE_USER'}, $ENV{'REMOTE_PASSWORD'});

    # 桼Ȥ˥ꥯȤϤ֤줿쥹ݥ󥹤ޤ
    $res = $ua->request($req);

    # 쥹ݥ󥹤η̤åޤ
    if ($res->is_success == 0) {
        # 쥹ݥ󥹥顼
        $$errmsg[$L_DISP] = $LANG{$ENV{$DISPLANG}}{'ERR_POST_REQUEST'} . "(" . $posturl . ")";
        $$errmsg[$L_LOG] = $LANG{$LOGLANG}{'ERR_POST_REQUEST'} . "(" . $posturl . ")";
        return -1;
    }

    $$result = $res->content;

    return 0;
}


#
# POSTμ¹Է̥å
#
# []
#       arg0    
#       arg1    顼
#
# [֤]
#       0       OK
#       1       POSTб顼
#

sub check_post_method
{
    my ($posturl, $postdata, $errmsg) = @_;
    my $result;

    if (send_post_method ($posturl, $postdata, \$result, $errmsg) == -1) {
        return -1;
    }

    if ($result ne $POSTRESULT) {
         $$errmsg[$L_DISP] = $LANG{$ENV{$DISPLANG}}{'ERR_POST_REQUEST2'} . "(" . $result . ")";
         $$errmsg[$L_LOG] = $LANG{$LOGLANG}{'ERR_POST_REQUEST2'} . "(" . $result . ")";
         return 1;
    }

    return 0;
}

#
# POST᥽åɤФȯ
#
# []
#       arg0    POSTURL
#       arg1    POSTѥǡ
#       arg2    顼
#
# [֤]
#       0       OK
#       1       POSTб顼
#      -1       ³顼
#
#

sub send_allpost
{
    my ($urllist, $postdata, $errmsg) = @_;
    my $url;
    my $ret;
    my @localerr;
    my $errflag = 0;

    # оݥФФ
    foreach $url (@$urllist) {

        # ݥȤ򥵡Ф
        $ret = check_post_method ($url, $postdata, \@localerr);

        if ($errflag != 0) {
            $$errmsg[$L_DISP] .= "\n";
            $$errmsg[$L_LOG] .= "\n";
        }

        # ƱФǥ顼ȯ
        if ($ret != 0) {
            $$errmsg[$L_DISP] .= $localerr[$L_DISP];
            $$errmsg[$L_LOG] .= $localerr[$L_LOG];
            $errflag = 1;
        }
    }

    return $errflag;
}

1;

==> DhcpAdmin-1.01.tar.gz: DhcpAdmin/lib/libpost.pl <==
#
# dhcpadmin
#
# Copyright (C) 2008 DesigNET, INC.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

##########################################################
#
# POST饤֥
#
# $RCSfile: libpost.pl,v $
# $Revision: 1.11 $
# $Date: 2013/02/20 06:24:51 $
#
##########################################################

use strict;
use LWP::UserAgent;
use MIME::Base64;

##################饤֥ꥰХ##################
my $HTTPAGENT="DHCPADMIN";
my $CONTENTTYPE="application/x-www-form-urlencoded";
my $POSTSETCODE="&postset=1";
my $POSTRESULT="RET:OK";

#
# POST᥽åȯ
#
# []
#	arg0	POSTURL
#	arg1	POSTѥǡ
#	arg2	
#	arg3	顼
#
# [֤]
#	0	OK
#      -1	³顼
#
#

sub send_post_method
{
    my ($posturl, $postdata, $result, $errmsg) = @_;
    my $ua;
    my $req;
    my $res;
    my $decoded;

    # Ķѿǧڥѥɤ򥻥å
    $ENV{'HTTP_AUTHORIZATION'} =~ s/Basic //;
    $decoded = decode_base64($ENV{'HTTP_AUTHORIZATION'});
    $decoded =~ s/$ENV{'REMOTE_USER'}://;
    $ENV{'REMOTE_PASSWORD'} = $decoded;

    # ꥯȳ
    $ua = new LWP::UserAgent;
    $ua->agent($HTTPAGENT . $ua->agent);

    # ꥯȤޤ
    $req = new HTTP::Request POST => $posturl;
    $req->content_type($CONTENTTYPE);
    $req->content($postdata . $POSTSETCODE);
    $req->authorization_basic($ENV{'REMOTE_USER'}, $ENV{'REMOTE_PASSWORD'});

    # 桼Ȥ˥ꥯȤϤ֤줿쥹ݥ󥹤ޤ
    $res = $ua->request($req);

    # 쥹ݥ󥹤η̤åޤ
    if ($res->is_success == 0) {
        # 쥹ݥ󥹥顼
        $$errmsg[$L_DISP] = $LANG{$ENV{$DISPLANG}}{'ERR_POST_REQUEST'} . "(" . $posturl . ")";
        $$errmsg[$L_LOG] = $LANG{$LOGLANG}{'ERR_POST_REQUEST'} . "(" . $posturl . ")";
        return -1;
    }

    $$result = $res->content;

    return 0;
}


#
# POSTμ¹Է̥å
#
# []
#       arg0    
#       arg1    顼
#
# [֤]
#       0       OK
#       1       POSTб顼
#

sub check_post_method
{
    my ($posturl, $postdata, $errmsg) = @_;
    my $result;

    if (send_post_method ($posturl, $postdata, \$result, $errmsg) == -1) {
        return -1;
    }

    if ($result ne $POSTRESULT) {
         $$errmsg[$L_DISP] = $LANG{$ENV{$DISPLANG}}{'ERR_POST_REQUEST2'} . "(" . $result . ")";
         $$errmsg[$L_LOG] = $LANG{$LOGLANG}{'ERR_POST_REQUEST2'} . "(" . $result . ")";
         return 1;
    }

    return 0;
}

#
# POST᥽åɤФȯ
#
# []
#       arg0    POSTURL
#       arg1    POSTѥǡ
#       arg2    顼
#
# [֤]
#       0       OK
#       1       POSTб顼
#      -1       ³顼
#
#

sub send_allpost
{
    my ($urllist, $postdata, $errmsg) = @_;
    my $url;
    my $ret;
    my @localerr;
    my $errflag = 0;

    # оݥФФ
    foreach $url (@$urllist) {

        # ݥȤ򥵡Ф
        $ret = check_post_method ($url, $postdata, \@localerr);

        if ($errflag != 0) {
            $$errmsg[$L_DISP] .= "\n";
            $$errmsg[$L_LOG] .= "\n";
        }

        # ƱФǥ顼ȯ
        if ($ret != 0) {
            $$errmsg[$L_DISP] .= $localerr[$L_DISP];
            $$errmsg[$L_LOG] .= $localerr[$L_LOG];
            $errflag = 1;
        }
    }

    return $errflag;
}

1;
